@@ -8,7 +8,7 @@
 #################################################################
 
 ##Author: Christos Zamantzas <christos.zamantzas@gmail.com>
-Version = '1.1-5'
+Version = '1.1-6'
 
 import os
 import sys
@@ -20,7 +20,6 @@ from PyQt4.QtGui import *
 from PyQt4.QtCore import *
 from PyQt4.QtMaemo5 import *
 from swappolubeUI import *
-from swappolubeSettings import *
 
 ##############################################################
 
@@ -30,8 +29,8 @@ PathSystem     = '/etc/event.d'                 # main path
 ConfigTemp     = 'swappolube_config_temp'       # name of temp config file
 ConfigCustom   = 'configCustom.py'              # name of custom config file
 ConfigMain     = 'tuning'                       # tuning file
-PathSystemUi   = '/etc/systemui'
-ConfigSystemUi = 'swappolube.xml'
+PathSystemUi   = '/etc/systemui'                # path to the storage of xml files for the power key menu
+ConfigSystemUi = 'swappolube.xml'               # name of the apllications' xml file for the power key menu
 
 ##############################################################
 
